package com.jiuqi.syntax;

import java.util.HashMap;

/* loaded from: com_jiuqi_syntax.jar:com/jiuqi/syntax/DataCell.class */
public final class DataCell {
    public static final int NONE_KIND = 0;
    public static final int YEAR_KIND = 1;
    public static final int HALFYEAR_KIND = 2;
    public static final int SEASON_KIND = 3;
    public static final int MONTH_KIND = 4;
    public static final int TENDAY_KIND = 5;
    public static final int WEEK_KIND = 6;
    public static final int DAY_KIND = 7;
    public static final int CUSTOM_KIND = 8;
    public static final int GRID_ROW_KIND = 9;
    public static final int GRID_COL_KIND = 10;
    public static final int MAX_TERM_VALUE = 9999;
    public static final int SUCC_TERM_BASE = 10000;
    public static final int STAT_NONE = 0;
    public static final int STAT_SUM = 1;
    public static final int STAT_COUNT = 2;
    public static final int STAT_MAX = 3;
    public static final int STAT_MIN = 4;
    public static final int STAT_AVG = 5;
    public static final int STAT_FIRST = 6;
    public static final int STAT_LAST = 7;
    public static final int STAT_LJ = 8;
    public static final int STAT_XJHZ = 10;
    public static final int STAT_AUTOSUM = 9;
    public int statMode;
    public static int DC_NEW_COUNT = 0;
    public static int DC_LIVE_COUNT = 0;
    public static final String[] KindSigns = {"", "N", "H", "J", "Y", "X", "Z", "R", "B", "行", "栏"};
    public static final String[] KindChinaSigns = {"", "年", "半年", "季", "月", "旬", "周", "日", "期", "行", "栏"};
    public static final String[] StatSigns = {"", "SUM", "COUNT", "MAX", "MIN", "AVG", "FIRST", "LAST", "LJ", "AUTOSUM", "XJHZ"};
    public String taskName = "";
    public int year = 0;
    public int termKind = 0;
    public int term = 0;
    public boolean isZB = true;
    public String zbName = "";
    public String tableName = "";
    public int row = 0;
    public int col = 0;
    public boolean fetchMean = false;
    public boolean hasCond = false;
    public String condition = "";
    public HashMap dimens = null;
    public Object dimenInfos = null;
    public Object statItem = null;
    public int tableOffset = 0;
    public int offset = 0;
    public int dimSeq = -1;

    public static int kindSignToInt(String s) {
        for (int i = 1; i < KindSigns.length; i++) {
            if (s.equalsIgnoreCase(KindSigns[i]) || s.equalsIgnoreCase(KindChinaSigns[i])) {
                return i;
            }
        }
        return 0;
    }

    public static String kindIntToSign(int k) {
        return (k < 0 || k >= KindSigns.length) ? "" : KindSigns[k];
    }

    public static String kindIntToChinaSign(int k) {
        return (k < 0 || k >= KindChinaSigns.length) ? "" : KindChinaSigns[k];
    }

    public static int statSignToInt(String s) {
        for (int i = 0; i < StatSigns.length; i++) {
            if (StatSigns[i].compareToIgnoreCase(s) == 0) {
                return i;
            }
        }
        return -1;
    }

    public static String statIntToSign(int i) {
        return (i < 0 || i >= StatSigns.length) ? "" : StatSigns[i];
    }

    public DataCell() {
        DC_NEW_COUNT++;
        DC_LIVE_COUNT++;
    }

    public void init() {
        this.taskName = "";
        this.year = 0;
        this.termKind = 0;
        this.term = 0;
        this.isZB = true;
        this.zbName = "";
        this.tableName = "";
        this.row = 0;
        this.col = 0;
        this.fetchMean = false;
        this.hasCond = false;
        this.condition = "";
        if (this.dimens != null) {
            this.dimens.clear();
        }
        this.statMode = 0;
        this.dimenInfos = null;
        this.statItem = null;
        this.tableOffset = 0;
        this.offset = 0;
    }

    public void assign(DataCell source) {
        this.taskName = source.taskName;
        this.year = source.year;
        this.termKind = source.termKind;
        this.term = source.term;
        this.isZB = source.isZB;
        this.zbName = source.zbName;
        this.tableName = source.tableName;
        this.row = source.row;
        this.col = source.col;
        this.fetchMean = source.fetchMean;
        this.hasCond = source.hasCond;
        this.condition = source.condition;
        if (this.dimens != null) {
            this.dimens.clear();
        }
        if (source.dimens != null) {
            if (this.dimens == null) {
                this.dimens = new HashMap(source.dimens.size());
            }
            this.dimens.putAll(source.dimens);
        }
        this.dimenInfos = source.dimenInfos;
        this.statItem = source.statItem;
        this.statMode = source.statMode;
        this.tableOffset = source.tableOffset;
        this.offset = source.offset;
        this.dimSeq = source.dimSeq;
    }

    public String toString() {
        StringBuffer stringBuffer = new StringBuffer();
        if (this.isZB) {
            stringBuffer.append("[").append(this.zbName);
            if (this.fetchMean) {
                stringBuffer.append("$");
            }
        } else {
            stringBuffer.append(this.tableName).append("[").append(this.row).append(",").append(this.col);
        }
        if (this.year != 0) {
            stringBuffer.append(",").append(this.year).append("N");
        }
        if (this.term != 0) {
            stringBuffer.append(",").append(this.term).append(kindIntToSign(this.termKind));
        } else if (this.termKind != 0) {
            stringBuffer.append(",").append(kindIntToSign(this.termKind));
        }
        if (this.hasCond) {
            stringBuffer.append(",'").append(this.condition).append("'");
        }
        if (this.dimens != null && !this.dimens.isEmpty()) {
            for (String s : this.dimens.keySet()) {
                stringBuffer.append(",").append(s).append("=\"").append((String) this.dimens.get(s)).append("\"");
            }
        }
        if (this.statMode != 0) {
            stringBuffer.append(",").append(statIntToSign(this.statMode));
        }
        stringBuffer.append("]");
        if (!this.taskName.equals("")) {
            stringBuffer.append("@").append(this.taskName);
        }
        return stringBuffer.toString();
    }

    protected void finalize() throws Throwable {
        DC_LIVE_COUNT--;
        super.finalize();
    }

    public static void main(String[] args) {
        System.out.println("str1:" + "KB01[42,1]".hashCode() + "," + hash("KB01[42,1]"));
        System.out.println("str2:" + "KB01[48,1]".hashCode() + "," + hash("KB01[48,1]"));
    }

    private static int hash(Object x) {
        int h = x.hashCode();
        int h2 = h + ((h << 9) ^ (-1));
        int h3 = h2 ^ (h2 >>> 14);
        int h4 = h3 + (h3 << 4);
        return h4 ^ (h4 >>> 10);
    }
}
